@@ -38,8 +38,9 @@ class MessageReader:
     topicAndPartition = TopicAndPartition
     consumerConfig = TalosClientConfig
     simpleConsumer = SimpleConsumer
-    consumerClient = ConsumerClient
     messageClient = MessageClient
+    consumerClient = ConsumerClient
+    queryOffsetClient = ConsumerClient
 
     # outer - checkPoint can be used only one time, burn after reading to prevent
     # partitionFetcher re - lock() and re - use outer - checkPoint again by consumer re - balance
@@ -71,11 +72,14 @@ class MessageReader:
     def set_message_processor(self, messageProcessor=None):
         self.messageProcessor = messageProcessor
 
+    def set_message_client(self, messageClient=None):
+        self.messageClient = messageClient
+
     def set_consumer_client(self, consumerClient=None):
         self.consumerClient = consumerClient
 
-    def set_message_client(self, messageClient=None):
-        self.messageClient = messageClient
+    def set_query_offset_client(self, queryOffsetClient=None):
+        self.queryOffsetClient = queryOffsetClient
 
     def set_outer_checkpoint(self, outerCheckpoint=None):
         self.outerCheckPoint = outerCheckpoint
