@@ -9,10 +9,8 @@ from talos.thrift.topic.ttypes import TopicTalosResourceName
 from talos.admin.TalosAdmin import TalosAdmin
 from talos.client.TalosClientConfig import TalosClientConfig
 from talos.client.TalosClientFactory import TalosClientFactory
-from talos.client.ScheduleInfoCache import ScheduleInfoCache
 from talos.utils import Utils
 from talos.utils.Utils import ReadWriteLock
-from talos.utils.FalconWriter import FalconWriter
 from talos.consumer.MessageProcessorFactory import MessageProcessorFactory
 from talos.consumer.MessageReaderFactory import MessageReaderFactory
 from talos.thrift.consumer.ttypes import ConsumeUnit
@@ -22,7 +20,7 @@ from talos.thrift.consumer.ttypes import RenewRequest
 from talos.thrift.consumer.ttypes import LockWorkerRequest
 from talos.client.TalosErrors import InvalidArgumentError
 from talos.consumer.PartitionFetcher import PartitionFetcher
-from talos.client.TalosClientFactory import ConsumerClient
+from talos.thrift.common.ttypes import GalaxyTalosException
 from threading import Timer
 import logging
 import random
@@ -59,7 +57,6 @@ class TalosConsumer(object):
     talosConsumerConfig = TalosClientConfig
     talosClientFactory = TalosClientFactory
     talosAdmin = TalosAdmin
-    consumerClient = ConsumerClient
     readWriteLock = ReadWriteLock()
     isActive = bool
     reBalanceExecutor = threading.Thread
@@ -79,9 +76,6 @@ class TalosConsumer(object):
     workerInfoMap = dict
     partitionCheckPoint = dict
 
-    falconWriter = FalconWriter
-    consumerMonitorThread = Timer
-
     def __init__(self, consumerGroup=None, consumerConfig=None,
                  credential=None, topicName=None, messageProcessorFactory=None,
                  clientPrefix=None, talosResourceName=None, workerId=None,
@@ -106,8 +100,8 @@ class TalosConsumer(object):
         else:
             self.consumerClient = self.talosClientFactory.new_consumer_client()
             self.lockClient = self.talosClientFactory.new_consumer_client()
-            self.renewWorkerClient = self.talosClientFactory.new_consumer_client()
-            self.queryWorkerClient = self.talosClientFactory.new_consumer_client()
+            self.renewClient = self.talosClientFactory.new_consumer_client()
+            self.queryClient = self.talosClientFactory.new_consumer_client()
         if talosResourceName:
             self.topicTalosResourceName = talosResourceName
         else:
@@ -121,13 +115,6 @@ class TalosConsumer(object):
             self.partitionCheckPoint = partitionCheckPoint
         else:
             self.partitionCheckPoint = dict()
-        # get scheduleInfo
-        self.scheduleInfoCache = ScheduleInfoCache().get_schedule_info_cache(
-            topicTalosResourceName=self.topicTalosResourceName.topicTalosResourceName,
-            talosClientConfig=consumerConfig,
-            messageClient=self.talosClientFactory.new_message_client(),
-            talosClientFactory=self.talosClientFactory)
-        self.falconWriter = FalconWriter(falconUrl=consumerConfig.get_falcon_url())
         self.isActive = True
 
         logger.info("The worker: " + self.workerId + " is initializing...")
@@ -143,7 +130,6 @@ class TalosConsumer(object):
         self.init_check_partition_task()
         self.init_check_worker_info_task()
         self.init_renew_task()
-        self.init_consumer_monitor_task()
 
     #
     # Check Partition Task
@@ -189,14 +175,13 @@ class TalosConsumer(object):
             self.set_partition_number(topicPartitionNum)
             # call the re - balance task
             self.reBalanceExecutor = threading.Thread(target=self.re_balance_task)
-            self.reBalanceExecutor.setName("talos-consumer-reBalanceTask-" + self.topicName)
+            self.reBalanceExecutor.setName("reBalanceTask-" + self.topicName)
             self.reBalanceExecutor.start()
 
         self.partitionScheduledExecutor = Timer(interval=self.talosConsumerConfig
                                                 .get_check_partition_interval(),
                                                 function=self.check_partition_task)
-        self.partitionScheduledExecutor.setName("talos-consumer-checkPartitionTask-"
-                                                + self.topicName)
+        self.partitionScheduledExecutor.setName("checkPartitionTask-" + self.topicName)
         self.partitionScheduledExecutor.start()
 
     #
@@ -227,8 +212,7 @@ class TalosConsumer(object):
         self.workerScheduleExecutor = Timer(interval=self.talosConsumerConfig
                                             .get_check_worker_info_interval(),
                                             function=self.check_worker_info_task)
-        self.workerScheduleExecutor.setName("talos-consumer-checkWorkerInfoTask-"
-                                            + self.topicName)
+        self.workerScheduleExecutor.setName("checkWorkerInfoTask-" + self.topicName)
         self.workerScheduleExecutor.start()
 
     #
@@ -239,10 +223,7 @@ class TalosConsumer(object):
     # 'CheckWorkerInfoTask' takes charge of updating workerInfoMap
     #
     def re_balance_task(self):
-        try:
-            self.make_balance()
-        except Exception as e:
-            logger.error("Exception in make_balance" + str(traceback.format_exc()))
+        self.make_balance()
 
     #
     # ReNew Task(contains two sections per renew)
@@ -266,9 +247,12 @@ class TalosConsumer(object):
         maxRetry = self.talosConsumerConfig.get_renew_max_retry() + 1
         while maxRetry > 0:
             try:
-                renewResponse = self.renewWorkerClient.renew(renewRequest)
+                renewResponse = self.renewClient.renew(renewRequest)
             except Exception as e:
-                logger.error("Worker: " + self.workerId + " renew error: " + str(traceback.format_exc()))
+                if isinstance(e, GalaxyTalosException):
+                    logger.error(e.errMsg)
+                logger.error("Worker: " + self.workerId + " renew error: "
+                             + str(traceback.format_exc()))
                 continue
             maxRetry -= 1
 
@@ -298,22 +282,9 @@ class TalosConsumer(object):
         self.renewScheduleExecutor = Timer(interval=self.talosConsumerConfig
                                            .get_renew_check_interval(),
                                            function=self.renew_task)
-        self.renewScheduleExecutor.setName("talos-consumer-renewTask-" + self.topicName)
+        self.renewScheduleExecutor.setName("renewTask-" + self.topicName)
         self.renewScheduleExecutor.start()
 
-    def consumer_monitor_task(self):
-        try:
-            self.push_metric_data()
-        except Exception as throwable:
-            logger.error("push metric data to falcon failed." + str(traceback.format_exc()))
-
-        self.consumerMonitorThread = Timer(interval=self.talosConsumerConfig
-                                           .get_report_metric_interval_millis() / 1000,
-                                           function=self.consumer_monitor_task)
-        self.consumerMonitorThread.setName("talos-consumer-checkPartitionTask-"
-                                           + self.topicName)
-        self.consumerMonitorThread.start()
-
     def check_and_get_topic_info(self, topicTalosResourceName=None):
         topicName = Utils.get_topic_name_by_resource_name(
             str(topicTalosResourceName.topicTalosResourceName.topicTalosResourceName))
@@ -322,7 +293,8 @@ class TalosConsumer(object):
 
         if not resourceName == response.topicTalosResourceName.topicTalosResourceName:
             logger.info("The consumer initialize failed by topic not found")
-            raise InvalidArgumentError("The topic: " + resourceName + " not found")
+            raise InvalidArgumentError("The topic: " + resourceName +
+                                       " not found")
 
         self.set_partition_number(response.partitionNumber)
         self.topicTalosResourceName = topicTalosResourceName.topicTalosResourceName
@@ -343,6 +315,8 @@ class TalosConsumer(object):
             try:
                 lockWorkerResponse = self.lockClient.lock_worker(lockWorkerRequest)
             except Exception as e:
+                if isinstance(e, GalaxyTalosException):
+                    logger.error(e.errMsg)
                 logger.error("The worker: " + self.workerId + "register self got error: "
                              + str(traceback.format_exc()))
                 continue
@@ -359,7 +333,7 @@ class TalosConsumer(object):
     def get_worker_info(self):
         queryWorkerRequest = QueryWorkerRequest(self.consumerGroup,
                                                 self.topicTalosResourceName)
-        queryWorkerResponse = self.queryWorkerClient.query_worker(queryWorkerRequest)
+        queryWorkerResponse = self.queryClient.query_worker(queryWorkerRequest)
 
         # if queryWorkerInfoMap size equals 0,
         # it represents hbase failed error, do not update local map
@@ -388,8 +362,8 @@ class TalosConsumer(object):
         else:
             # calculate the target sequence
             sum = 0
-            min = copyPartitionNum / workerNumber
-            remainder = copyPartitionNum % workerNumber
+            min = int(copyPartitionNum / workerNumber)
+            remainder = int(copyPartitionNum % workerNumber)
             # add max by remainder
             index = 0
             while index < remainder:
@@ -403,10 +377,7 @@ class TalosConsumer(object):
                 targetList.append(min)
                 sum += min
                 index += 1
-            try:
-                assert sum == copyPartitionNum
-            except AssertionError as error:
-                raise error
+            assert sum == copyPartitionNum
 
         # sort target by descending
         targetList.sort(reverse=True)
@@ -483,11 +454,7 @@ class TalosConsumer(object):
             i += 1
 
         # steal or release partition lock or reached a balance state
-        try:
-            assert not (len(toStealList) > 0 and len(toReleaseList) > 0)
-        except AssertionError as error:
-            raise error
-
+        assert not (len(toStealList) > 0 and len(toReleaseList) > 0)
         if len(toStealList) > 0:
             self.steal_partition_lock(toStealList)
         elif len(toReleaseList) > 0:
@@ -527,11 +494,7 @@ class TalosConsumer(object):
                     + " partition: " + str(toReleaseList))
         # stop read, commit offset, unlock the partition async
         for partitionId in toReleaseList:
-            try:
-                assert partitionId in self.partitionFetcherMap
-            except AssertionError as error:
-                logger.warning("Worker: %s try to release partition: %d failed: %s", self.workerId, partitionId, error)
-                continue
+            assert partitionId in self.partitionFetcherMap
             self.partitionFetcherMap.get(partitionId).unlock()
             del self.partitionFetcherMap[partitionId]
 
@@ -546,20 +509,16 @@ class TalosConsumer(object):
 
     def get_idle_partitions(self):
         self.readWriteLock.read_acquire()
-        try:
-            assert self.partitionNumber > 0
-            idlePartitions = []
-            i = 0
-            while i < self.partitionNumber:
-                idlePartitions.append(i)
-                i += 1
-            for valueList in self.workerInfoMap.values():
-                for partitionId in valueList:
-                    idlePartitions.remove(partitionId)
-        except Exception as error:
-            raise error
-        finally:
-            self.readWriteLock.read_release()
+        assert self.partitionNumber > 0
+        idlePartitions = []
+        i = 0
+        while i < self.partitionNumber:
+            idlePartitions.append(i)
+            i += 1
+        for valueList in self.workerInfoMap.values():
+            for partitionId in valueList:
+                idlePartitions.remove(partitionId)
+        self.readWriteLock.read_release()
         return idlePartitions
 
     def shut_down_fetcher(self):
@@ -595,37 +554,23 @@ class TalosConsumer(object):
         self.partitionScheduledExecutor = Timer(interval=self.talosConsumerConfig
                                                 .get_check_partition_interval(),
                                                 function=self.check_partition_task)
-        self.partitionScheduledExecutor.setName("talos-consumer-checkPartitionTask-" + self.topicName)
+        self.partitionScheduledExecutor.setName("checkPartitionTask-" + self.topicName)
         self.partitionScheduledExecutor.start()
 
     def init_check_worker_info_task(self):
         self.workerScheduleExecutor = Timer(interval=self.talosConsumerConfig
                                             .get_check_worker_info_interval(),
                                             function=self.check_worker_info_task)
-        self.workerScheduleExecutor.setName("talos-consumer-checkWorkerInfoTask-" + self.topicName)
+        self.workerScheduleExecutor.setName("checkWorkerInfoTask-" + self.topicName)
         self.workerScheduleExecutor.start()
 
     def init_renew_task(self):
         self.renewScheduleExecutor = Timer(interval=self.talosConsumerConfig
                                            .get_renew_check_interval(),
                                            function=self.renew_task)
-        self.renewScheduleExecutor.setName("talos-consumer-renewTask-" + self.topicName)
+        self.renewScheduleExecutor.setName("renewTask-" + self.topicName)
         self.renewScheduleExecutor.start()
 
-    def init_consumer_monitor_task(self):
-        if self.talosConsumerConfig.is_open_client_monitor():
-            self.consumerMonitorThread = Timer(interval=self.talosConsumerConfig
-                                               .get_report_metric_interval_millis() / 1000,
-                                               function=self.consumer_monitor_task)
-            self.consumerMonitorThread.setName("talos-consumer-monitor-" + self.topicName)
-            self.consumerMonitorThread.start()
-
-    def push_metric_data(self):
-        jsonArray = []
-        for key, value in self.partitionFetcherMap.items():
-            jsonArray += value.get_falcon_data()
-        self.falconWriter.push_falcon_data(jsonArray)
-
     #
     # First stop CheckPartition and CheckWorkerInfo Task and then shutdown all fetcher,
     # that avoid thread exit failed caused by rebalance partition when shutDownAllFetcher
@@ -640,8 +585,5 @@ class TalosConsumer(object):
         self.workerScheduleExecutor.cancel()
         self.shut_down_fetcher()
         self.renewScheduleExecutor.cancel()
-        if self.talosConsumerConfig.is_open_client_monitor():
-            self.consumerMonitorThread.cancel()
-        self.scheduleInfoCache.shut_down(self.topicTalosResourceName)
         self.isActive = False
         logger.info("Worker: " + self.workerId + " shutdown.")
